@@ -6,7 +6,7 @@ use Carp;
 use Time::HiRes;
 use Config;
 
-our $VERSION = '0.07';
+our $VERSION = '0.08';
 our $DEBUG = $ENV{FORKS_QUEUE_DEBUG} || 0;
 
 our $NOTIFY_OK = $ENV{FORKS_QUEUE_NOTIFY} // do {
@@ -24,6 +24,14 @@ sub new {
     my $class = shift;
     my %opts = (%OPTS, @_);
 
+    if ($opts{remote}) {
+        require Net::Objwrap;
+        if (-f $opts{remote}) {
+            my $q = Net::Objwrap::unwrap($opts{remote});
+            return $q;
+        }
+    }
+
     if ($opts{impl}) {
         my $pkg = delete $opts{impl};
         if ($pkg =~ /[^\w:]/) {
@@ -193,7 +201,7 @@ Forks::Queue - queue that can be shared across processes
 
 =head1 VERSION
 
-0.07
+0.08
 
 =head1 SYNOPSIS
 
@@ -337,6 +345,21 @@ C<list> option. The argument must be an array reference.
 If the C<join> option is specified, the contents of the list
 could be added to an already existing queue.
 
+=item * C<< remote => FILENAME >>
+
+Enable proxy access to a queue that may be running on another host.
+If the given filename exists, this option will get C<Forks::Queue>
+to read server connection information from the file, establish a
+network connection to the server, and provide a proxy object
+that implements the C<Forks::Queue> interface and manipulates the
+queue on the remote server. If the filename does not exist,
+then C<Forks::Queue> will create a new queue object and launch a
+server to make the queue available remotely, writing the details
+about how to connect to the server into the file.
+
+Remote access to queues is provided through the L<Net::Objwrap>
+distribution, which is bundled with C<Forks::Queue> v0.08.
+
 =back
 
 See the global L<"%OPTS"/"%OPTS"> variable for information about
@@ -769,5 +792,7 @@ See http://dev.perl.org/licenses/ for more information.
 #
 #     priorities
 #     Directory implementation (see Queue::Dir)
-#     network implementation with simple client-server
+# _X_ network implementation with simple client-server
 #     even better thread support, 2nd signal from main to threads?
+#
+
