@@ -8,7 +8,7 @@ use Time::HiRes;
 use base 'Forks::Queue';
 use 5.010;    #  using  // //=  operators
 
-our $VERSION = '0.07';
+our $VERSION = '0.08';
 our $DEBUG;
 *DEBUG = \$Forks::Queue::DEBUG;
 
@@ -141,6 +141,12 @@ sub new {
             carp "Forks::Queue::new: 'list' option must be an array ref";
         }
     }
+
+    if ($opts{remote}) {
+        require Net::Objwrap;
+        Net::Objwrap::wrap($opts{remote},$self);
+    }
+    
     return $self;
 }
 
@@ -1071,7 +1077,7 @@ Forks::Queue::File - file-based implementation of Forks::Queue
 
 =head1 VERSION
 
-0.07
+0.08
 
 =head1 SYNOPSIS
 
